@@ -28,6 +28,7 @@ import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
@@ -38,6 +39,8 @@ import java.util.Arrays;
 import java.util.List;
 import java.util.Random;
 
+import com.sun.jna.platform.mac.CoreFoundation.CFDictionaryRef;
+import org.junit.Assert;
 import org.junit.Test;
 
 import com.sun.jna.Memory;
@@ -209,6 +212,7 @@ public class CoreFoundationTest {
         CFStringRef oneStr = CFStringRef.createCFString("one");
 
         // Key does not exist, returns null
+        assertEquals(0L, dict.getCount());
         assertFalse(dict.getValueIfPresent(oneStr, null));
         Pointer cfNull = dict.getValue(oneStr);
         assertNull(cfNull);
@@ -223,6 +227,7 @@ public class CoreFoundationTest {
         IntByReference one = new IntByReference(1);
         CFNumberRef cfOne = CF.CFNumberCreate(null, CFNumberType.kCFNumberIntType.typeIndex(), one);
         dict.setValue(oneStr, cfOne);
+        assertEquals(1L, dict.getCount());
 
         assertTrue(dict.getValueIfPresent(oneStr, null));
         Pointer result = dict.getValue(oneStr);
@@ -240,9 +245,139 @@ public class CoreFoundationTest {
         result = dict.getValue(onePtr);
         CFStringRef strRef = new CFStringRef(result);
         assertEquals("one", strRef.stringValue());
+        assertEquals(2L, dict.getCount());
 
         oneStr.release();
         cfOne.release();
         dict.release();
     }
+
+    @Test
+    public void testCFStringRefByReference() {
+        CFStringRef key = CFStringRef.createCFString("key");
+        CFStringRef value = CFStringRef.createCFString("value");
+
+        CFMutableDictionaryRef dict = CF.CFDictionaryCreateMutable(null, new CFIndex(2), null, null);
+        dict.setValue(key, value);
+
+        // test getStringRefValue()
+        CFStringRef.ByReference byRef = new CFStringRef.ByReference();
+        assertTrue(dict.getValueIfPresent(key, byRef));
+        assertTrue(CF.CFEqual(value, byRef.getStringRefValue()));
+
+        // test constructor()
+        assertNull(new CFStringRef.ByReference().getValue());
+
+        // test constructor(null)
+        assertNull(new CFStringRef.ByReference(null).getValue());
+
+        // test constructor(CFStringRef)
+        assertTrue(CF.CFEqual(new CFStringRef.ByReference(key).getStringRefValue(), key));
+
+        // test setValue(null)
+        assertNotNull(byRef.getStringRefValue());
+        byRef.setValue(null);
+        assertNull(byRef.getStringRefValue());
+
+        // test setValue(CFStringRef), getValue()
+        byRef.setValue(value.getPointer());
+        assertTrue(CF.CFEqual(value, byRef.getStringRefValue()));
+        assertEquals(value.getPointer(), byRef.getValue());
+
+        // test setValue(CFDictionaryRef)
+        try {
+            byRef.setValue(dict.getPointer());
+            Assert.fail("must fail");
+        } catch (ClassCastException cce) {
+            // as it should be
+        }
+
+        CF.CFRelease(key);
+        CF.CFRelease(value);
+        CF.CFRelease(dict);
+    }
+
+    @Test
+    public void testCFDictionaryRefByReference() {
+        CFStringRef key = CFStringRef.createCFString("key");
+
+        CFMutableDictionaryRef value = CF.CFDictionaryCreateMutable(null, new CFIndex(2), null, null);
+        value.setValue(key, key);
+
+        CFMutableDictionaryRef dict = CF.CFDictionaryCreateMutable(null, new CFIndex(2), null, null);
+        dict.setValue(key, value);
+
+        // test getDictionaryRefValue()
+        CFDictionaryRef.ByReference byRef = new CFDictionaryRef.ByReference();
+        assertTrue(dict.getValueIfPresent(key, byRef));
+        assertTrue(CF.CFEqual(value, byRef.getDictionaryRefValue()));
+
+        // test constructor()
+        assertNull(new CFDictionaryRef.ByReference().getValue());
+
+        // test constructor(null)
+        assertNull(new CFDictionaryRef.ByReference(null).getValue());
+
+        // test constructor(CFDictionaryRef)
+        assertTrue(CF.CFEqual(new CFDictionaryRef.ByReference(dict).getDictionaryRefValue(), dict));
+
+        // test setValue(null)
+        assertNotNull(byRef.getDictionaryRefValue());
+        byRef.setValue(null);
+        assertNull(byRef.getDictionaryRefValue());
+
+        // test setValue(CFDictionaryRef), getValue()
+        byRef.setValue(value.getPointer());
+        assertTrue(CF.CFEqual(value, byRef.getDictionaryRefValue()));
+        assertEquals(value.getPointer(), byRef.getValue());
+
+        // test setValue(CFStringRef)
+        try {
+            byRef.setValue(key.getPointer());
+            Assert.fail("must fail");
+        } catch (ClassCastException cce) {
+            // as it should be
+        }
+
+        CF.CFRelease(key);
+        CF.CFRelease(value);
+        CF.CFRelease(dict);
+    }
+
+    @Test
+    public void testCFGetTypeID() {
+        CFStringRef s1 = CFStringRef.createCFString("s1");
+        assertEquals(CF.CFStringGetTypeID(), CF.CFGetTypeID(s1.getPointer()));
+        assertEquals(CF.CFStringGetTypeID(), CF.CFGetTypeID(s1));
+        s1.release();
+    }
+
+    @Test
+    public void testCFEqual() {
+        CFStringRef s1 = CFStringRef.createCFString("s1");
+        CFStringRef s1_the_same = CFStringRef.createCFString("s1");
+        CFStringRef s2 = CFStringRef.createCFString("s2");
+
+        assertTrue(CF.CFEqual(s1, s1));
+        assertTrue(CF.CFEqual(s1, s1_the_same));
+
+        assertFalse(CF.CFEqual(s1, s2));
+
+        CFMutableDictionaryRef dict1 = CF.CFDictionaryCreateMutable(null, new CFIndex(2), null, null);
+        dict1.setValue(s1, s1);
+        CFMutableDictionaryRef dict2 = CF.CFDictionaryCreateMutable(null, new CFIndex(2), null, null);
+        dict2.setValue(s1, s1);
+
+        assertNotEquals(dict1.getPointer(), dict2.getPointer());
+        assertTrue(CF.CFEqual(dict1, dict2));
+
+        dict2.setValue(s1, s2);
+        assertFalse(CF.CFEqual(dict1, dict2));
+
+        CF.CFRelease(dict1);
+        CF.CFRelease(dict2);
+        CF.CFRelease(s1);
+        CF.CFRelease(s1_the_same);
+        CF.CFRelease(s2);
+    }
 }
