@@ -1,23 +1,23 @@
 /* Copyright (c) 2009-2015 Timothy Wall, All Rights Reserved
  *
- * The contents of this file is dual-licensed under 2 
- * alternative Open Source/Free licenses: LGPL 2.1 or later and 
+ * The contents of this file is dual-licensed under 2
+ * alternative Open Source/Free licenses: LGPL 2.1 or later and
  * Apache License 2.0. (starting with JNA version 4.0.0).
- * 
- * You can freely decide which license you want to apply to 
+ *
+ * You can freely decide which license you want to apply to
  * the project.
- * 
+ *
  * You may obtain a copy of the LGPL License at:
- * 
+ *
  * http://www.gnu.org/licenses/licenses.html
- * 
+ *
  * A copy is also included in the downloadable source code package
  * containing JNA, in file "LGPL2.1".
- * 
+ *
  * You may obtain a copy of the Apache License at:
- * 
+ *
  * http://www.apache.org/licenses/
- * 
+ *
  * A copy is also included in the downloadable source code package
  * containing JNA, in file "AL2.0".
  */
@@ -130,7 +130,7 @@ public class PerformanceTest extends TestCase implements Paths {
         Pointer pb = Native.getDirectBufferPointer(b);
 
         String mname = Platform.MATH_LIBRARY_NAME;
-        MathInterface mlib = Native.loadLibrary(mname, MathInterface.class);
+        MathInterface mlib = Native.load(mname, MathInterface.class);
         Function f = NativeLibrary.getInstance(mname).getFunction("cos");
 
         ///////////////////////////////////////////
@@ -163,8 +163,8 @@ public class PerformanceTest extends TestCase implements Paths {
         long resp;
         long argv;
         if (Native.POINTER_SIZE == 4) {
-            b.putInt(0, (int)Structure.FFIType.get(double.class).peer);
-            cif = Native.ffi_prep_cif(0, 1, Structure.FFIType.get(double.class).peer, types);
+            b.putInt(0, (int)Structure.FFIType.get(double.class).getPointer().peer);
+            cif = Native.ffi_prep_cif(0, 1, Structure.FFIType.get(double.class).getPointer().peer, types);
             resp = pb.peer + 4;
             argv = pb.peer + 12;
             double INPUT = 42;
@@ -178,8 +178,8 @@ public class PerformanceTest extends TestCase implements Paths {
             delta = System.currentTimeMillis() - start;
         }
         else {
-            b.putLong(0, Structure.FFIType.get(double.class).peer);
-            cif = Native.ffi_prep_cif(0, 1, Structure.FFIType.get(double.class).peer, types);
+            b.putLong(0, Structure.FFIType.get(double.class).getPointer().peer);
+            cif = Native.ffi_prep_cif(0, 1, Structure.FFIType.get(double.class).getPointer().peer, types);
             resp = pb.peer + 8;
             argv = pb.peer + 16;
             double INPUT = 42;
@@ -222,7 +222,7 @@ public class PerformanceTest extends TestCase implements Paths {
                 }
             });
         }
-        CInterface clib = Native.loadLibrary(cname, CInterface.class, options);
+        CInterface clib = Native.load(cname, CInterface.class, options);
 
         ///////////////////////////////////////////
         // getpid
@@ -305,10 +305,10 @@ public class PerformanceTest extends TestCase implements Paths {
         System.out.println("memset (JNA direct primitives): " + delta + "ms");
 
         if (Native.POINTER_SIZE == 4) {
-            b.putInt(0, (int)Structure.FFIType.get(Pointer.class).peer);
-            b.putInt(4, (int)Structure.FFIType.get(int.class).peer);
-            b.putInt(8, (int)Structure.FFIType.get(int.class).peer);
-            cif = Native.ffi_prep_cif(0, 3, Structure.FFIType.get(Pointer.class).peer, types);
+            b.putInt(0, (int)Structure.FFIType.get(Pointer.class).getPointer().peer);
+            b.putInt(4, (int)Structure.FFIType.get(int.class).getPointer().peer);
+            b.putInt(8, (int)Structure.FFIType.get(int.class).getPointer().peer);
+            cif = Native.ffi_prep_cif(0, 3, Structure.FFIType.get(Pointer.class).getPointer().peer, types);
             resp = pb.peer + 12;
             argv = pb.peer + 16;
             start = System.currentTimeMillis();
@@ -325,10 +325,10 @@ public class PerformanceTest extends TestCase implements Paths {
             delta = System.currentTimeMillis() - start;
         }
         else {
-            b.putLong(0, Structure.FFIType.get(Pointer.class).peer);
-            b.putLong(8, Structure.FFIType.get(int.class).peer);
-            b.putLong(16, Structure.FFIType.get(long.class).peer);
-            cif = Native.ffi_prep_cif(0, 3, Structure.FFIType.get(Pointer.class).peer, types);
+            b.putLong(0, Structure.FFIType.get(Pointer.class).getPointer().peer);
+            b.putLong(8, Structure.FFIType.get(int.class).getPointer().peer);
+            b.putLong(16, Structure.FFIType.get(long.class).getPointer().peer);
+            cif = Native.ffi_prep_cif(0, 3, Structure.FFIType.get(Pointer.class).getPointer().peer, types);
             resp = pb.peer + 24;
             argv = pb.peer + 32;
             start = System.currentTimeMillis();
@@ -405,8 +405,8 @@ public class PerformanceTest extends TestCase implements Paths {
         System.out.println("strlen (JNA direct - Buffer): " + delta + "ms");
 
         if (Native.POINTER_SIZE == 4) {
-            b.putInt(0, (int)Structure.FFIType.get(Pointer.class).peer);
-            cif = Native.ffi_prep_cif(0, 1, Structure.FFIType.get(int.class).peer, types);
+            b.putInt(0, (int)Structure.FFIType.get(Pointer.class).getPointer().peer);
+            cif = Native.ffi_prep_cif(0, 1, Structure.FFIType.get(int.class).getPointer().peer, types);
             resp = pb.peer + 4;
             argv = pb.peer + 8;
             start = System.currentTimeMillis();
@@ -423,8 +423,8 @@ public class PerformanceTest extends TestCase implements Paths {
             delta = System.currentTimeMillis() - start;
         }
         else {
-            b.putLong(0, Structure.FFIType.get(Pointer.class).peer);
-            cif = Native.ffi_prep_cif(0, 1, Structure.FFIType.get(long.class).peer, types);
+            b.putLong(0, Structure.FFIType.get(Pointer.class).getPointer().peer);
+            cif = Native.ffi_prep_cif(0, 1, Structure.FFIType.get(long.class).getPointer().peer, types);
             resp = pb.peer + 8;
             argv = pb.peer + 16;
             start = System.currentTimeMillis();
@@ -477,7 +477,7 @@ public class PerformanceTest extends TestCase implements Paths {
 
         ///////////////////////////////////////////
         // Callbacks
-        TestInterface tlib = Native.loadLibrary("testlib", TestInterface.class);
+        TestInterface tlib = Native.load("testlib", TestInterface.class);
         start = System.currentTimeMillis();
         TestInterface.Int32Callback cb = new TestInterface.Int32Callback() {
             @Override
