@@ -1,23 +1,23 @@
 /* Copyright (c) 2007 Timothy Wall, All Rights Reserved
  *
- * The contents of this file is dual-licensed under 2 
- * alternative Open Source/Free licenses: LGPL 2.1 or later and 
+ * The contents of this file is dual-licensed under 2
+ * alternative Open Source/Free licenses: LGPL 2.1 or later and
  * Apache License 2.0. (starting with JNA version 4.0.0).
- * 
- * You can freely decide which license you want to apply to 
+ *
+ * You can freely decide which license you want to apply to
  * the project.
- * 
+ *
  * You may obtain a copy of the LGPL License at:
- * 
+ *
  * http://www.gnu.org/licenses/licenses.html
- * 
+ *
  * A copy is also included in the downloadable source code package
  * containing JNA, in file "LGPL2.1".
- * 
+ *
  * You may obtain a copy of the Apache License at:
- * 
+ *
  * http://www.apache.org/licenses/
- * 
+ *
  * A copy is also included in the downloadable source code package
  * containing JNA, in file "AL2.0".
  */
@@ -92,7 +92,7 @@ public class UnionTest extends TestCase {
 
     public void testFieldOffsets() {
         StructUnion u = new StructUnion();
-        assertEquals("Wrong union size: " + u, Pointer.SIZE, u.size());
+        assertEquals("Wrong union size: " + u, Native.POINTER_SIZE, u.size());
         u.setType(u.testStruct.getClass());
         u.write();
         assertEquals("Wrong struct member base address",
@@ -132,7 +132,7 @@ public class UnionTest extends TestCase {
         final int VALUE = 0x12345678;
         // write an instance of a direct union class to memory
         StructUnion u = new StructUnion();
-        assertEquals("Wrong union size: " + u, Pointer.SIZE, u.size());
+        assertEquals("Wrong union size: " + u, Native.POINTER_SIZE, u.size());
         IntStructure intStruct = new IntStructure();
         intStruct.value = VALUE;
         u.setTypedValue(intStruct);
@@ -158,7 +158,7 @@ public class UnionTest extends TestCase {
 
     public void testReadTypedUnion() {
         StructUnion u = new StructUnion();
-        assertEquals("Wrong union size: " + u, Pointer.SIZE, u.size());
+        assertEquals("Wrong union size: " + u, Native.POINTER_SIZE, u.size());
         final int VALUE = 0x12345678;
         u.getPointer().setInt(0, VALUE);
         assertEquals("int structure not read properly", VALUE, ((IntStructure) u.getTypedValue(IntStructure.class)).value);
@@ -171,12 +171,12 @@ public class UnionTest extends TestCase {
         assertNotNull("Type information is missing for union instance", u.getTypeInfo());
         if (Native.POINTER_SIZE == 4) {
             assertEquals("Type size should be that of largest field if no field is active",
-                         Structure.getTypeInfo(BigTestStructure.class).getInt(0),
+                         Structure.getTypeInfo(BigTestStructure.class).getPointer().getInt(0),
                          u.getTypeInfo().getInt(0));
         }
         else {
             assertEquals("Type size should be that of largest field if no field is active",
-                         Structure.getTypeInfo(BigTestStructure.class).getLong(0),
+                         Structure.getTypeInfo(BigTestStructure.class).getPointer().getLong(0),
                          u.getTypeInfo().getLong(0));
         }
         u.setType(int.class);
@@ -184,12 +184,12 @@ public class UnionTest extends TestCase {
         assertNotNull("Type information is missing for union instance after type set", u.getTypeInfo());
         if (Native.POINTER_SIZE == 4) {
             assertEquals("Type size should be that of largest field if any field is active",
-                         Structure.getTypeInfo(BigTestStructure.class).getInt(0),
+                         Structure.getTypeInfo(BigTestStructure.class).getPointer().getInt(0),
                          u.getTypeInfo().getInt(0));
         }
         else {
             assertEquals("Type size should be that of largest field if any field is active",
-                         Structure.getTypeInfo(BigTestStructure.class).getLong(0),
+                         Structure.getTypeInfo(BigTestStructure.class).getPointer().getLong(0),
                          u.getTypeInfo().getLong(0));
         }
     }
